@@ -29,13 +29,13 @@ gtt_help_popup(GtkWidget *widget, gpointer data)
 {
 	GError *err = NULL;
 	char * section = data;
-	if (NULL == section) section = "";
+	if ("" == section) section = NULL;
 	gnome_help_display ("gnotime", section, &err);
 	if (err)
 	{
 		GtkWidget *mb;
 		mb = gtk_message_dialog_new (
-		         GTK_WINDOW (widget),
+		         GTK_IS_WINDOW(widget) ? GTK_WINDOW (widget) : NULL,
 		         GTK_DIALOG_MODAL,
 		         GTK_MESSAGE_ERROR,
 		         GTK_BUTTONS_CLOSE,
