@@ -1,4 +1,4 @@
-/*   Config file input/output handling for GnoTime 
+/*   Config file input/output handling for GnoTime
  *   Copyright (C) 1997,98 Eckehard Berns
  *   Copyright (C) 2001,2002,2003 Linas Vepstas <linas@linas.org>
  *
@@ -34,22 +34,20 @@
 #include "file-io.h"
 #include "gconf-io.h"
 #include "gtt.h"
+#include "menus.h"
 #include "plug-in.h"
 #include "prefs.h"
 #include "proj.h"
+#include "proj_p.h"
 #include "timer.h"
 #include "toolbar.h"
 
-#ifdef DEBUG
+#ifdef USE_GTT_DEBUG_FILE
 #define GTT_CONF "/gtt-DEBUG"
 #else /* not DEBUG */
 #define GTT_CONF "/" GTT_APP_NAME
 #endif /* not DEBUG */
 
-
-/* FIXME: we should not extern plist; but for now its ok */
-extern GList * plist;
-
 static const char * gtt_config_filepath = NULL;
 
 int cur_proj_id = -1;
@@ -62,7 +60,7 @@ int save_count = 0;
 /* Configuration file I/O routines:
  * Note that this file supports reading from several old, 'obsolete'
  * config file formats taht GTT has used over the years.  We support
- * these reads so that users do not get left out in the cold when 
+ * these reads so that users do not get left out in the cold when
  * upgrading from old versions of GTT.  All 'saves' are in the new
  * file format (currently, GConf-2).
  *
@@ -120,7 +118,6 @@ project_list_load_old(void)
 {
 	FILE *f;
 	const char *realname;
-	GList *pl, *t;
 	GttProject *proj = NULL;
 	char s[1024];
 	int i;
@@ -129,17 +126,17 @@ project_list_load_old(void)
 	realname = build_rc_name_old();
 	gtt_config_filepath = realname;
 
-	if (NULL == (f = fopen(realname, "rt"))) 
+	if (NULL == (f = fopen(realname, "rt")))
 	{
 		gtt_err_set_code(GTT_CANT_OPEN_FILE);
+		gtt_config_filepath = ""; /* Don't spew obsolete filename to new users */
 #ifdef ENOENT
 		if (errno == ENOENT) return;
 #endif
 		g_warning("could not open %s\n", realname);
 		return;
 	}
-	pl = gtt_get_project_list();
-	plist = NULL;
+	printf ("GTT: Info: Importing .gtimetrackerrc config file\n");
 
 	_n = config_show_tb_new;
 	_c = config_show_tb_ccp;
@@ -165,13 +162,7 @@ project_list_load_old(void)
 			/* show seconds? */
 			config_show_secs = (s[3] == 'n');
 		} else if (s[0] == 'b') {
-			if (s[1] == 'i') {
-				/* show icons in the toolbar */
-				config_show_tb_icons = (s[4] == 'n');
-			} else if (s[1] == 't') {
-				/* show text in the toolbar */
-				config_show_tb_texts = (s[4] == 'n');
-			} else if (s[1] == 'p') {
+			if (s[1] == 'p') {
 				/* show tooltips */
 				config_show_tb_tips = (s[4] == 'n');
 			} else if (s[1] == 'h') {
@@ -218,7 +209,7 @@ project_list_load_old(void)
 
 			/* new project */
 			proj = gtt_project_new();
-			gtt_project_list_append(proj);
+			gtt_project_list_append(master_list, proj);
 			ever_secs = atol(s);
 			for (i = 0; s[i] != ' '; i++) ;
 			i++;
@@ -234,10 +225,6 @@ project_list_load_old(void)
 	if ((errno) && (!feof(f))) goto err;
 	fclose(f);
 
-	t = plist;
-	plist = pl;
-	project_list_destroy();
-	plist = t;
 	gtt_project_list_compute_secs();
 
 	if (config_show_statusbar)
@@ -265,8 +252,6 @@ err:
 	fclose(f);
 	gtt_err_set_code (GTT_FILE_CORRUPT);
 	g_warning("error reading %s\n", realname);
-	project_list_destroy();
-	plist = pl;
 }
 
 
@@ -299,15 +284,17 @@ gtt_load_gnome_config (const char *prefix)
 	prefix_len = 0;
 	if (prefix) prefix_len = strlen (prefix);
 	s = g_new (char, prefix_len + TOKLEN);
-	strcpy (s, prefix);
+	if (!s) return;
+	s[0] = 0;
+	if (prefix) strcpy (s, prefix);
 	p = &s[prefix_len];
 
 	/* If already running, and we are over-loading a new file,
 	 * then save the currently running project, and try to set it
 	 * running again ... */
-	if (gtt_project_get_title(cur_proj) && (!first_proj_title)) 
+	if (gtt_project_get_title(cur_proj) && (!first_proj_title))
 	{
-		/* we need to strdup because title is freed when 
+		/* we need to strdup because title is freed when
 		 * the project list is destroyed ... */
 		first_proj_title = g_strdup (gtt_project_get_title (cur_proj));
 	}
@@ -327,11 +314,11 @@ gtt_load_gnome_config (const char *prefix)
    config_idle_timeout = GET_INT("/Misc/IdleTimeout=300");
    config_autosave_period = GET_INT("/Misc/AutosavePeriod=60");
 
-	/* Reset the main window width and height to the values 
-	 * last stored in the config file.  Note that if the user 
-	 * specified command-line flags, then the command line 
+	/* Reset the main window width and height to the values
+	 * last stored in the config file.  Note that if the user
+	 * specified command-line flags, then the command line
 	 * over-rides the config file. */
-	if (!geom_place_override) 
+	if (!geom_place_override)
 	{
 		int x, y;
 		x = GET_INT("/Geometry/X=10");
@@ -381,8 +368,6 @@ gtt_load_gnome_config (const char *prefix)
 
 
 	/* ------------ */
-	config_show_tb_icons = GET_BOOL("/Toolbar/ShowIcons=true");
-	config_show_tb_texts = GET_BOOL("/Toolbar/ShowTexts=true");
 	config_show_tb_tips = GET_BOOL("/Toolbar/ShowTips=true");
 	config_show_tb_new = GET_BOOL("/Toolbar/ShowNew=true");
 	config_show_tb_ccp = GET_BOOL("/Toolbar/ShowCCP=false");
@@ -411,7 +396,7 @@ gtt_load_gnome_config (const char *prefix)
 	/* ------------ */
 	save_count = GET_INT("/Data/SaveCount=0");
 	config_data_url = GET_STR("/Data/URL=" XML_DATA_FILENAME);
-	if (NULL == config_data_url) 
+	if (NULL == config_data_url)
 	{
 		config_data_url = XML_DATA_FILENAME;
 	}
@@ -420,8 +405,8 @@ gtt_load_gnome_config (const char *prefix)
 	num = 0;
 	for (i = 0; -1 < num; i++) {
 		g_snprintf(p, TOKLEN, "/CList/ColumnWidth%d=-1", i);
-		num = gnome_config_get_int(s);   
-		if (-1 < num) 
+		num = gnome_config_get_int(s);
+		if (-1 < num)
 		{
 			ctree_set_col_width (global_ptw, i, num);
 		}
@@ -431,7 +416,9 @@ gtt_load_gnome_config (const char *prefix)
 	num = GET_INT("/Misc/NumReports=0");
 	if (0 < num)
 	{
-		for (i = num-1; i >= 0 ; i--) 
+		GnomeUIInfo * reports_menu;
+		reports_menu =  g_new0 (GnomeUIInfo, num+1);
+		for (i = num-1; i >= 0 ; i--)
 		{
 			GttPlugin *plg;
 			char * name, *path, *tip;
@@ -443,8 +430,21 @@ gtt_load_gnome_config (const char *prefix)
 			tip = gnome_config_get_string(s);
 			plg = gtt_plugin_new (name, path);
 			plg->tooltip = g_strdup (tip);
+
+			/* fixup */
+			reports_menu[i].type = GNOME_APP_UI_ITEM;
+			reports_menu[i].user_data = plg;
+			reports_menu[i].label = name;
+			reports_menu[i].hint = tip;
+			reports_menu[i].unused_data = NULL;
+			reports_menu[i].pixmap_type = GNOME_APP_PIXMAP_STOCK;
+			reports_menu[i].pixmap_info = GNOME_STOCK_BLANK;
+			reports_menu[i].accelerator_key = 0;
+			reports_menu[i].ac_mods = (GdkModifierType) 0;
 		}
-	} 
+		reports_menu[num].type = GNOME_APP_UI_ENDOFINFO;
+		gtt_set_reports_menu (GNOME_APP(app_window), reports_menu);
+	}
 
 	/* The old-style config file also contained project data
 	 * in it. Read this data, if present.  The new config file
@@ -455,24 +455,21 @@ gtt_load_gnome_config (const char *prefix)
 	num = GET_INT("/Misc/NumProjects=0");
 	if (0 < num)
 	{
-		/* start with a clean slate */
-		project_list_destroy();
-
-		for (i = 0; i < num; i++) 
+		for (i = 0; i < num; i++)
 		{
 			GttProject *proj;
 			time_t ever_secs, day_secs;
 
 			proj = gtt_project_new();
-			gtt_project_list_append(proj);
+			gtt_project_list_append(master_list, proj);
 			g_snprintf(p, TOKLEN, "/Project%d/Title", i);
 			gtt_project_set_title(proj, gnome_config_get_string(s));
-	
+
 			/* Match the last running project */
 			if (i == cur_proj_id) {
 				cur_proj_set(proj);
 			}
-	
+
 			g_snprintf(p, TOKLEN, "/Project%d/Desc", i);
 			gtt_project_set_desc(proj, gnome_config_get_string(s));
 			g_snprintf(p, TOKLEN, "/Project%d/SecsEver=0", i);
@@ -482,7 +479,7 @@ gtt_load_gnome_config (const char *prefix)
 			gtt_project_compat_set_secs (proj, ever_secs, day_secs, last_timer);
 		}
 		gtt_project_list_compute_secs();
-	} 
+	}
 
 	/* redraw the GUI */
 	if (config_show_statusbar)
@@ -502,7 +499,7 @@ gtt_load_gnome_config (const char *prefix)
 	    (_t != config_show_tb_timer) ||
 	    (_o != config_show_tb_pref) ||
 	    (_h != config_show_tb_help) ||
-	    (_e != config_show_tb_exit)) 
+	    (_e != config_show_tb_exit))
 	{
 		update_toolbar_sections();
 	}
@@ -525,16 +522,21 @@ gtt_load_config (void)
 		gtt_config_filepath = NULL;
 		return;
 	}
-			  
+
 	/* gnotime breifly used the gnome2 gnome_config file */
 	if (gnome_config_has_section (GTT_CONF"/Misc"))
 	{
 		printf ("GTT: Info: Importing ~/.gnome2/" GTT_CONF " file\n");
 		gtt_load_gnome_config (GTT_CONF);
 		gtt_config_filepath = gnome_config_get_real_path (GTT_CONF);
+
+		/* The data file will be in the same directory ...
+		 * so prune filename to get the directory */
+		char *p = strrchr (gtt_config_filepath, '/');
+		if (p) *p = 0x0;
 		return;
 	}
-			
+
 	/* Look for a gnome-1.4 era gnome_config file */
 	h = g_get_home_dir();
 	s = g_new (char, strlen (h) + 120);
@@ -554,9 +556,8 @@ gtt_load_config (void)
 		return;
 	}
 	g_free (s);
-	
+
 	/* OK, try to load the oldest file format */
-	printf ("GTT: Info: Importing .gtimetrackerrc config file\n");
 	project_list_load_old ();
 	config_data_url = XML_DATA_FILENAME;
 	return;
@@ -564,26 +565,27 @@ gtt_load_config (void)
 
 /* ======================================================= */
 
-void 
+void
 gtt_post_data_config (void)
 {
-	/* Assume we've already read the XML data, and just 
+	/* Assume we've already read the XML data, and just
 	 * set the current project */
 	cur_proj_set (gtt_project_locate_from_id (cur_proj_id));
 
-	/* Over-ride the current project based on the 
+	/* Over-ride the current project based on the
 	 * command-line setting */
 	if (first_proj_title)
 	{
 		GList *node;
-		for (node = gtt_get_project_list(); node; node = node->next) 
+		node = gtt_project_list_get_list(master_list);
+		for (; node; node = node->next)
 		{
 			GttProject *prj = node->data;
 			if (!gtt_project_get_title(prj)) continue;
 
 			/* set project based on command line */
-			if (0 == strcmp(gtt_project_get_title(prj), 
-					first_proj_title)) 
+			if (0 == strcmp(gtt_project_get_title(prj),
+					first_proj_title))
 			{
 				cur_proj_set(prj);
 				break;
@@ -595,7 +597,7 @@ gtt_post_data_config (void)
 	first_proj_title = NULL;
 
 	/* reset the clocks, if needed */
-	if (0 < last_timer) 
+	if (0 < last_timer)
 	{
 		set_last_reset (last_timer);
 		zero_on_rollover (time(0));
@@ -603,13 +605,13 @@ gtt_post_data_config (void)
 
 	/* if a project is running, then set it running again,
 	 * otherwise be sure to stop the clock. */
-	if (FALSE == run_timer) 
+	if (FALSE == run_timer)
 	{
 		cur_proj_set (NULL);
 	}
 }
-	
-void 
+
+void
 gtt_post_ctree_config (void)
 {
 	const char * xpn = NULL;
@@ -636,12 +638,12 @@ gtt_post_ctree_config (void)
 void
 gtt_save_config(void)
 {
-   gtt_gconf_save(); 
+   gtt_gconf_save();
 }
 
 /* ======================================================= */
 
-const char * 
+const char *
 gtt_get_config_filepath (void)
 {
 	return gtt_config_filepath;
