@@ -146,8 +146,7 @@ gtt_gconf_save (void)
 	SETSTR ("/Display/ExpanderState", xpn);
 
 	/* ------------- */
-	SETBOOL ("/Toolbar/ShowIcons", config_show_tb_icons);
-	SETBOOL ("/Toolbar/ShowTexts", config_show_tb_texts);
+	SETBOOL ("/Toolbar/ShowToolbar", config_show_toolbar);
 	SETBOOL ("/Toolbar/ShowTips", config_show_tb_tips);
 	SETBOOL ("/Toolbar/ShowNew", config_show_tb_new);
 	SETBOOL ("/Toolbar/ShowCCP", config_show_tb_ccp);
@@ -216,6 +215,7 @@ gtt_gconf_save (void)
 	g_snprintf(s, sizeof (s), "%ld", time(0));
 	SETSTR ("/Misc/LastTimer", s);
 	SETINT ("/Misc/IdleTimeout", config_idle_timeout);
+	SETINT ("/Misc/NoProjectTimeout", config_no_project_timeout);
 	SETINT ("/Misc/AutosavePeriod", config_autosave_period);
 	SETINT ("/Misc/TimerRunning", timer_is_running());
 	SETINT ("/Misc/CurrProject", gtt_project_get_id (cur_proj));
@@ -358,6 +358,7 @@ gtt_gconf_load (void)
    cur_proj_id = GETINT("/Misc/CurrProject", -1);
 
    config_idle_timeout = GETINT ("/Misc/IdleTimeout", 300);
+   config_no_project_timeout = GETINT ("/Misc/NoProjectTimeout", 300);
    config_autosave_period = GETINT ("/Misc/AutosavePeriod", 60);
    config_daystart_offset = GETINT ("/Misc/DayStartOffset", 0);
    config_weekstart_offset = GETINT ("/Misc/WeekStartOffset", 0);
@@ -416,8 +417,7 @@ gtt_gconf_load (void)
 
 
 	/* ------------ */
-	config_show_tb_icons   = GETBOOL ("/Toolbar/ShowIcons", TRUE);
-	config_show_tb_texts   = GETBOOL ("/Toolbar/ShowTexts", TRUE);
+	config_show_toolbar    = GETBOOL ("/Toolbar/ShowToolbar", TRUE);
 	config_show_tb_tips    = GETBOOL ("/Toolbar/ShowTips", TRUE);
 	config_show_tb_new     = GETBOOL ("/Toolbar/ShowNew", TRUE);
 	config_show_tb_ccp     = GETBOOL ("/Toolbar/ShowCCP", FALSE);
