@@ -36,7 +36,7 @@
 #include <sys/wait.h>
 #endif
 
-#include <qof.h>
+#include <qof/qof.h>
 
 #include "app.h"
 #include "ctree.h"
@@ -49,6 +49,7 @@
 #include "menus.h"
 #include "menucmd.h"
 #include "prefs.h"
+#include "proj.h"
 #include "timer.h"
 #include "toolbar.h"
 #include "xml-gtt.h"
@@ -57,6 +58,7 @@ char *first_proj_title = NULL;  /* command line over-ride */
 
 static gboolean first_time_ever = FALSE;  /* has gtt ever run before? */
 
+GttProjectList *master_list = NULL;
 
 const char *
 gtt_gettext(const char *s)
@@ -67,14 +69,11 @@ gtt_gettext(const char *s)
 	return s;
 }
 
-
-
-
 static char *build_lock_fname(void)
 {
 	GString *str;
 	static char *fname = NULL;
-	
+
 	if (fname != NULL) return fname;
 
 	/* note it will handle unset "HOME" fairly gracefully */
@@ -97,7 +96,7 @@ static void lock_gtt(void)
 	FILE *f;
 	char *fname;
 	gboolean warn = FALSE;
-	
+
 	fname = build_lock_fname ();
 
 	/* if the pid file exists and such a process exists
@@ -114,8 +113,8 @@ static void lock_gtt(void)
 		}
 		fclose(f);
 	}
-		
-	if (warn) 
+	
+	if (warn)
 	{
 		GtkWidget *warning;
 		warning = gnome_message_box_new(
@@ -130,8 +129,11 @@ static void lock_gtt(void)
 			exit(0);
 		}
 	}
-	if (NULL == (f = fopen(fname, "wt"))) {
+	f = fopen(fname, "wt");
+	if (NULL == f)
+	{
 		g_warning(_("Cannot create pid-file!"));
+		return;
 	}
 	fprintf(f, "%d\n", getpid());
 	fclose(f);
@@ -139,7 +141,7 @@ static void lock_gtt(void)
 
 
 
-void 
+void
 unlock_gtt(void)
 {
 	log_exit();
@@ -161,7 +163,7 @@ unlock_gtt(void)
 	/* gnome shutdown */
 #if 0
 	gnome_vfs_shutdown ();
-#endif  
+#endif
 }
 
 /* Return a 1 if the indicated directory did not exist, and
@@ -209,7 +211,7 @@ post_read_data(void)
 	gtt_post_data_config();
 
 	err_init();
-	ctree_setup(global_ptw, gtt_get_project_list());
+	ctree_setup(global_ptw, master_list);
 	gtt_post_ctree_config();
 	menu_set_states();
 	toolbar_set_states();
@@ -222,7 +224,7 @@ post_read_data(void)
 	app_show();
 }
 
-static void 
+static void
 read_data_err_run_or_abort (GtkDialog *w, gint response_id)
 {
 	if ((GTK_RESPONSE_OK == response_id) ||
@@ -249,7 +251,7 @@ resolve_old_path (const char * pathfrag)
 		/* If not an absolute filepath, look for the file in the same dir
 		 * where the gtt config file was found. */
 		confpath = gtt_get_config_filepath ();
-		if (NULL == confpath)
+		if (NULL == confpath || 0 == confpath[0])
 		{
 			fullpath = gnome_config_get_real_path (pathfrag);
 		}
@@ -292,7 +294,7 @@ resolve_path (const char * pathfrag)
 }
 
 
-static void 
+static void
 read_data(void)
 {
 	GttErrCode xml_errcode;
@@ -310,14 +312,14 @@ read_data(void)
 	xml_errcode = gtt_err_get_code();
 
 	read_is_ok = (GTT_NO_ERR == xml_errcode);
-	
+
 	/* If the xml file read bombed because the file doesn't exist,
 	 * and yet the project list isn't null, that's because we read
-	 * and old-format config file that had the proejcts in it.
+	 * and old-format config file that had the projects in it.
 	 * This is not an error. This is OK.
 	 */
 	read_is_ok |= (GTT_CANT_OPEN_FILE == xml_errcode) &&
-	               gtt_get_project_list();
+	               gtt_project_list_get_list(master_list);
 
 	/* Its possible that the read failed because this is the
 	 * first time that gnotime is being run.  In this case,
@@ -343,7 +345,7 @@ read_data(void)
 
 	/* Else handle an error. */
 	errmsg = gtt_err_to_string (xml_errcode, xml_filepath);
-	qmsg = g_strconcat (errmsg, 
+	qmsg = g_strconcat (errmsg,
 			_("Do you want to continue?"),
 			NULL);
 
@@ -354,10 +356,10 @@ read_data(void)
 	         GTK_BUTTONS_YES_NO,
 	         qmsg);
 	g_signal_connect (G_OBJECT(mb), "response",
-	         G_CALLBACK (read_data_err_run_or_abort), 
+	         G_CALLBACK (read_data_err_run_or_abort),
 	         NULL);
 	gtk_widget_show (mb);
-	g_free (qmsg); 
+	g_free (qmsg);
 	g_free (errmsg);
 }
 
@@ -367,7 +369,7 @@ post_read_config(void)
 	read_data();
 }
 
-static void 
+static void
 read_config_err_run_or_abort (GtkDialog *w, gint response_id)
 {
 	if ((GTK_RESPONSE_OK == response_id) ||
@@ -383,7 +385,7 @@ read_config_err_run_or_abort (GtkDialog *w, gint response_id)
 	}
 }
 
-static void 
+static void
 read_config(void)
 {
 	GttErrCode conf_errcode;
@@ -394,13 +396,13 @@ read_config(void)
 
 	/* Catch ... */
 	conf_errcode = gtt_err_get_code();
-	if (GTT_NO_ERR != conf_errcode) 
+	if (GTT_NO_ERR != conf_errcode)
 	{
 		const char *fp;
 		char *errmsg, *qmsg;
 		fp = gtt_get_config_filepath();
 		errmsg = gtt_err_to_string (conf_errcode, fp);
-		qmsg = g_strconcat (errmsg, 
+		qmsg = g_strconcat (errmsg,
 			_("Shall I setup a new configuration?"),
 			NULL);
 
@@ -411,13 +413,13 @@ read_config(void)
 		         GTK_BUTTONS_YES_NO,
 		         qmsg);
 		g_signal_connect (G_OBJECT(mb), "response",
-		         G_CALLBACK (read_config_err_run_or_abort), 
+		         G_CALLBACK (read_config_err_run_or_abort),
 		         NULL);
 		gtk_widget_show (mb);
-		g_free (qmsg); 
+		g_free (qmsg);
 		g_free (errmsg);
 	}
-	else 
+	else
 	{
 		post_read_config();
 	}
@@ -426,7 +428,7 @@ read_config(void)
 
 #if DEVEL_VERSION_WARNING
 /* used only to display development version warning messsage */
-static void 
+static void
 beta_run_or_abort(GtkWidget *w, gint butnum)
 {
 	if (butnum == 1)
@@ -444,7 +446,7 @@ beta_run_or_abort(GtkWidget *w, gint butnum)
  * every time that its called.  Its structured so that older copies
  * are saved exponentially less often.  This results in a logarithmic
  * distribution of backups; a realatively small number of files, of which
- * few are old, and most are younger.  The idea is that this 
+ * few are old, and most are younger.  The idea is that this
  * should get you out of a jam, no matter how old your mistake is.
  * Sure wish I'd had this implemented earlier in my debugging cycle :-(
  *
@@ -484,15 +486,15 @@ make_backup (const char * filename)
 	new_name = g_new0 (char, len+20);
 	strcpy (old_name, filename);
 	strcpy (new_name, filename);
-		
+	
 
 	if ((0 < suffix) && (0<lm))
 	{
 		/* Shuffle files, but preserve datestamps */
-		/* Don't report errors, as user may have erased 
+		/* Don't report errors, as user may have erased
 		 * some of these older files by hand */
-		sprintf (new_name+len, ".%d.%d", suffix, lm); 
-		sprintf (old_name+len, ".%d.2", suffix-1); 
+		sprintf (new_name+len, ".%d.%d", suffix, lm);
+		sprintf (old_name+len, ".%d.2", suffix-1);
 		rc = stat (old_name, &old_stat);
 		rc += rename (old_name, new_name);
 		if (0 == rc)
@@ -502,8 +504,8 @@ make_backup (const char * filename)
 			utime (new_name, &ub);
 		}
 	}
-	
-	sprintf (new_name+len, ".0.%d",lm); 
+
+	sprintf (new_name+len, ".0.%d",lm);
 	rc = stat (filename, &old_stat);
 	rc += rename (filename, new_name);
 	if (0 == rc)
@@ -517,7 +519,7 @@ make_backup (const char * filename)
 	g_free (new_name);
 }
 
-/* save_all() saves both data and config file, and does this 
+/* save_all() saves both data and config file, and does this
  * without involving the GUI.
  * It is a bit sloppy, in that if we get two errors in a row,
  * we'll miss the second one ... but what the hey, who cares.
@@ -605,7 +607,7 @@ save_projects (void)
 	gtt_err_set_code (GTT_NO_ERR);
 	gtt_xml_write_file (xml_filepath);
 
-	/* Try to handle a bizzare missing-directory error 
+	/* Try to handle a bizzare missing-directory error
 	 * by creating the directory, and trying again. */
 	errcode = gtt_err_get_code();
 	if (GTT_CANT_OPEN_FILE == errcode)
@@ -614,7 +616,7 @@ save_projects (void)
 		gtt_err_set_code (GTT_NO_ERR);
 		gtt_xml_write_file (xml_filepath);
 	}
-				  
+
 	/* Catch */
 	errcode = gtt_err_get_code();
 	if (GTT_NO_ERR != errcode)
@@ -695,14 +697,14 @@ static void
 got_signal (int sig)
 {
 	unlock_gtt ();
-	
+
 	/* whack thyself */
 	signal (sig, SIG_DFL);
 	kill (getpid (), sig);
 }
 
 
-static void 
+static void
 guile_inner_main(void *closure, int argc, char **argv)
 {
 	gtk_main();
@@ -710,13 +712,13 @@ guile_inner_main(void *closure, int argc, char **argv)
 }
 
 #if defined (HAVE_DECL_WNOHANG) && defined (HAVE_WAITPID)
-inline RETSIGTYPE sigchld_handler(int unused) 
+inline RETSIGTYPE sigchld_handler(int unused)
 {
 	while(waitpid(-1, NULL, WNOHANG) > 0) {}
 }
 #endif
 
-int 
+int
 main(int argc, char *argv[])
 {
 #if defined (HAVE_DECL_WNOHANG) || defined (HAVE_DECL_SA_NOCLDWAIT)
@@ -734,8 +736,8 @@ main(int argc, char *argv[])
 		{NULL, '\0', 0, NULL, 0}
 	};
 
-	gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv, 
-		                   GNOME_PARAM_POPT_TABLE, geo_options, 
+	gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
+		                   GNOME_PARAM_POPT_TABLE, geo_options,
 		                   GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-cromagnon.png");
 
@@ -786,6 +788,7 @@ main(int argc, char *argv[])
 	qof_query_init ();
 	qof_book_register ();
 	gtt_project_obj_register();
+	master_list = gtt_project_list_new();
 
 #if DEVEL_VERSION_WARNING
 	msgbox_ok_cancel(_("Warning"),
@@ -798,7 +801,7 @@ main(int argc, char *argv[])
 		"the www.gnome.org gnome-utils cvs with\n"
 		"cvs -z3 -d :pserver:anonymous@anoncvs.gnome.org:/cvs/gnome "
 		"checkout -r gnome-utils-1-4 gnome-utils\n",
-	     "Continue", "Exit", 
+	     "Continue", "Exit",
 		G_CALLBACK(beta_run_or_abort));
 #else
 	read_config();
