@@ -21,7 +21,7 @@
 
 #include <glade/glade.h>
 #include <gnome.h>
-#include <qof.h>
+#include <qof/qof.h>
 #include <string.h>
 
 #include "app.h"
@@ -60,8 +60,7 @@ int config_show_title_urgency = 1;
 int config_show_title_importance = 1;
 int config_show_title_status = 0;
 
-int config_show_tb_icons = 1;
-int config_show_tb_texts = 1;
+int config_show_toolbar = 1;
 int config_show_tb_tips = 1;
 int config_show_tb_new = 1;
 int config_show_tb_ccp = 0;
@@ -125,8 +124,7 @@ typedef struct _PrefsDialog
 	GtkEntry       *shell_start;
 	GtkEntry       *shell_stop;
 
-	GtkCheckButton *show_tb_icons;
-	GtkCheckButton *show_tb_texts;
+	GtkCheckButton *show_toolbar;
 	GtkCheckButton *show_tb_tips;
 	GtkCheckButton *show_tb_new;
 	GtkCheckButton *show_tb_ccp;
@@ -138,6 +136,7 @@ typedef struct _PrefsDialog
 	GtkCheckButton *show_tb_exit;
 
 	GtkEntry       *idle_secs;
+	GtkEntry       *no_project_secs;
 	GtkEntry       *daystart_secs;
 	GtkOptionMenu  *daystart_menu;
 	GtkOptionMenu  *weekstart_menu;
@@ -228,6 +227,26 @@ scan_time_string (const char *str)
 
 /* ============================================================== */
 
+static void 
+toolbar_sensitive_cb(GtkWidget *w, PrefsDialog *odlg)
+{
+	int state;
+	
+	state = GTK_TOGGLE_BUTTON(odlg->show_toolbar)->active;
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_new), state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_ccp), state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_journal), state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_pref), state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_timer), state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_prop), state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_help), state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->show_tb_exit), state);
+	
+	// gtk_widget_set_sensitive(odlg->logfilename_l, state);
+}
+
+/* ============================================================== */
+
 #define ENTRY_TO_CHAR(a, b) {                               \
    const char *s = gtk_entry_get_text(a);                   \
    if (s[0]) {                                              \
@@ -296,7 +315,7 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 		state = GTK_TOGGLE_BUTTON(odlg->show_secs)->active;
 		if (state != config_show_secs) {
 			config_show_secs = state;
-			ctree_setup (global_ptw, gtt_get_project_list());
+			ctree_setup (global_ptw, master_list);
 			update_status_bar();
 			if (status_bar)
 			gtk_widget_queue_resize(status_bar);
@@ -348,8 +367,7 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 		int change = 0;
 
 		/* toolbar */
-		config_show_tb_icons = GTK_TOGGLE_BUTTON(odlg->show_tb_icons)->active;
-		config_show_tb_texts = GTK_TOGGLE_BUTTON(odlg->show_tb_texts)->active;
+		config_show_toolbar = GTK_TOGGLE_BUTTON(odlg->show_toolbar)->active;
 		config_show_tb_tips = GTK_TOGGLE_BUTTON(odlg->show_tb_tips)->active;
 	
 		/* toolbar sections */
@@ -374,6 +392,7 @@ prefs_set(GnomePropertyBox * pb, gint page, PrefsDialog *odlg)
 	{
 		int change = 0;
 		config_idle_timeout = atoi(gtk_entry_get_text(GTK_ENTRY(odlg->idle_secs)));
+		config_no_project_timeout = atoi(gtk_entry_get_text(GTK_ENTRY(odlg->no_project_secs)));
 
 		/* Hunt for the hour-of night on which to start */
 		const char * buff = gtk_entry_get_text (odlg->daystart_secs);
@@ -478,8 +497,7 @@ options_dialog_set(PrefsDialog *odlg)
 	logfile_sensitive_cb(NULL, odlg);
 
 	/* toolbar sections */
-	SET_ACTIVE(tb_icons);
-	SET_ACTIVE(tb_texts);
+	SET_ACTIVE(toolbar);
 	SET_ACTIVE(tb_tips);
 	SET_ACTIVE(tb_new);
 	SET_ACTIVE(tb_ccp);
@@ -489,11 +507,16 @@ options_dialog_set(PrefsDialog *odlg)
 	SET_ACTIVE(tb_pref);
 	SET_ACTIVE(tb_help);
 	SET_ACTIVE(tb_exit);
+	
+	toolbar_sensitive_cb(NULL, odlg);
 
 	/* misc section */
 	g_snprintf(s, sizeof (s), "%d", config_idle_timeout);
 	gtk_entry_set_text(GTK_ENTRY(odlg->idle_secs), s);
 
+	g_snprintf(s, sizeof (s), "%d", config_no_project_timeout);
+	gtk_entry_set_text(GTK_ENTRY(odlg->no_project_secs), s);
+
 	/* Set the correct menu item based on current values */
 	int hour;
 	if (0<config_daystart_offset)
@@ -674,8 +697,13 @@ toolbar_options(PrefsDialog *dlg)
 	GtkWidget *w;
 	GladeXML *gtxml = dlg->gtxml;
 
-	TBWID (icons);
-	TBWID (texts);
+	w = GETCHWID ("show toolbar");
+	dlg->show_toolbar = GTK_CHECK_BUTTON(w);
+	
+	gtk_signal_connect(GTK_OBJECT(w), "clicked",
+		   GTK_SIGNAL_FUNC(toolbar_sensitive_cb),
+		   (gpointer *)dlg);
+	
 	TBWID (tips);
 	TBWID (new);
 	TBWID (ccp);
@@ -696,6 +724,9 @@ misc_options(PrefsDialog *dlg)
 	w = GETWID ("idle secs");
 	dlg->idle_secs = GTK_ENTRY(w);
 
+	w = GETWID ("no project secs");
+	dlg->no_project_secs = GTK_ENTRY(w);
+
 	w = GETWID ("daystart entry");
 	dlg->daystart_secs = GTK_ENTRY(w);
 
@@ -715,7 +746,7 @@ misc_options(PrefsDialog *dlg)
 static void 
 help_cb (GnomePropertyBox *propertybox, gint page_num, gpointer data)
 {
-	gtt_help_popup (propertybox, data);
+	gtt_help_popup (GTK_WIDGET(propertybox), data);
 }
 
 static PrefsDialog *
@@ -733,7 +764,7 @@ prefs_dialog_new (void)
 
 	gtk_signal_connect(GTK_OBJECT(dlg->dlg), "help",
 			   GTK_SIGNAL_FUNC(help_cb),
-			   "gnotime.xml#preferences");
+			   "preferences");
 
 	gtk_signal_connect(GTK_OBJECT(dlg->dlg), "apply",
 			   GTK_SIGNAL_FUNC(prefs_set), dlg);
