@@ -21,7 +21,7 @@
 #define __GTT_PROJ_H__
 
 #include <glib.h>
-#include <qof.h>
+#include <qof/qof.h>
 
 /* The data structures for GnoTime are written in a quasi-object-oriented
  * style.  All data is encapsulated in opaque structs, and can be accessed
@@ -40,28 +40,28 @@
 #endif /* TIME_WITH_SYS_TIME */
 
 
-/* hack alert -- these are hard-coded enums; they should 
- * probably be replaced by a system of user-defined 
+/* hack alert -- these are hard-coded enums; they should
+ * probably be replaced by a system of user-defined
  * enumerated values, especially for GttProjectStatus
  */
 
 
-typedef enum 
+typedef enum
 {
 	GTT_BILLABLE = 1,   /* billable time */
 	GTT_NOT_BILLABLE,   /* not billable to customer, internal only */
 	GTT_NO_CHARGE       /* shows on invoice as 'no charge/free' */
 } GttBillable;
 
-typedef enum 
+typedef enum
 {
 	GTT_REGULAR = 0,
 	GTT_OVERTIME,
 	GTT_OVEROVER,
 	GTT_FLAT_FEE
 } GttBillRate;
-		
-typedef enum 
+
+typedef enum
 {
 	GTT_HOLD = 0,	 /* needs review, will not appear on invoice */
 	GTT_BILL = 1,    /* print this on invoice, its done, ready */
@@ -78,13 +78,14 @@ typedef enum
 
 typedef enum
 {
-	GTT_NOT_STARTED = 0,  /* hack alert-- we should allow */
+	GTT_NO_STATUS = 0,
+	GTT_NOT_STARTED = 1,  /* hack alert-- we should allow */
 	GTT_IN_PROGRESS,      /* user-defined status states */
 	GTT_ON_HOLD,          /* wating for something */
 	GTT_CANCELLED,
 	GTT_COMPLETED
 } GttProjectStatus;
-		
+
 /* -------------------------------------------------------- */
 /* Query related things -- under construction */
 
@@ -95,7 +96,8 @@ typedef enum
 #define GTT_PROJECT_LATEST   "GttProjectLatest"
 
 /* -------------------------------------------------------- */
-/* The three basic structures */
+/* The four basic structures */
+typedef struct gtt_project_list_s GttProjectList;
 typedef struct gtt_project_s GttProject;
 typedef struct gtt_task_s GttTask;
 typedef struct gtt_interval_s GttInterval;
@@ -123,10 +125,10 @@ void 		gtt_project_destroy(GttProject *);
  */
 GttProject *	gtt_project_dup(GttProject *);
 
-/* The gtt_project_remove() routine will take the project out of 
- *    either the master list, or out of any parents' list of 
- *    sub-projects that it might below to.  As a result, this 
- *    project will dangle there -- don't loose it 
+/* The gtt_project_remove() routine will take the project out of
+ *    either the master list, or out of any parents' list of
+ *    sub-projects that it might below to.  As a result, this
+ *    project will dangle there -- don't loose it
  */
 void 		gtt_project_remove(GttProject *p);
 
@@ -138,7 +140,7 @@ void 		gtt_project_set_notes(GttProject *, const char *);
 void 		gtt_project_set_custid(GttProject *, const char *);
 
 /* These two routines return the title & desc strings.
- * Do *not* free these strings when done.  Note that 
+ * Do *not* free these strings when done.  Note that
  * are freed when project is deleted. */
 const char * 	gtt_project_get_title (GttProject *);
 const char * 	gtt_project_get_desc (GttProject *);
@@ -151,7 +153,7 @@ const char * 	gtt_project_get_custid (GttProject *);
  *    labelling it as 'old gtt data', and putting the time info
  *    into that task.  Depricated. Don't use in new code.
  */
-void		gtt_project_compat_set_secs (GttProject *proj, 
+void		gtt_project_compat_set_secs (GttProject *proj,
 			int secs_ever, int secs_day, time_t last_update);
 
 
@@ -171,11 +173,11 @@ double 		gtt_project_get_flat_fee (GttProject *);
 
 /* The gtt_project_set_min_interval() routine sets the smallest
  *    time unit, below which work intervals will not be recorded
- *    (and will instead be discarded).   Default is 3 seconds, 
+ *    (and will instead be discarded).   Default is 3 seconds,
  *    but it should be 60 seconds.
  *
  * The gtt_project_auto_merge_interval() routine sets the smallest
- *    time unit, below which work intervals will be merged into 
+ *    time unit, below which work intervals will be merged into
  *    prior work intervals rather than being counted as seperate.
  *    Default is 1 minute, but should be 5 minutes.
  */
@@ -187,12 +189,12 @@ void		gtt_project_set_auto_merge_gap (GttProject *, int);
 int		gtt_project_get_auto_merge_gap (GttProject *);
 
 /* Todo-list management stuff.
- * The estimated start date is when we expect to first start working 
- * on this project.  The estimated end date is when we expect to be 
+ * The estimated start date is when we expect to first start working
+ * on this project.  The estimated end date is when we expect to be
  * done working on this project.  The due date is the date that the
  * project is supposed to be finished.
  *
- * The sizing is the estimate (in seconds) of how long it will take to 
+ * The sizing is the estimate (in seconds) of how long it will take to
  * complete this task.  The precent-complete is the estimate of how
  * much of this project has been completed.
  *
@@ -201,12 +203,12 @@ int		gtt_project_get_auto_merge_gap (GttProject *);
  * this task is.  Note that things may be urgent, but not important
  * (Bob wants me to answer his email today, but I don't really care).
  * Things can be important but not urgent.  (Its important for me
- * to pass  this exam, but its not urgent -- I have all school-year 
+ * to pass  this exam, but its not urgent -- I have all school-year
  * to study for it.)
- * 
+ *
  * The project status indicates whether this is an ongoing project or
  * not.  We really should allow configurable values, so that users
- * could define multiple stages: e.g. 'testing', 'designing', 
+ * could define multiple stages: e.g. 'testing', 'designing',
  * 'on-hold', 'waiting for response', etc.
  */
 void     gtt_project_set_estimated_start (GttProject *, time_t);
@@ -235,7 +237,7 @@ int  		gtt_project_get_id (GttProject *);
 GttProject * 	gtt_project_locate_from_id (int prj_id);
 
 /* The gtt_project_add_notifier() routine allows anoter component
- *    (e.g. a GUI) to add a signal that will be called whenever the 
+ *    (e.g. a GUI) to add a signal that will be called whenever the
  *    time associated with a project changes. (except timers ???)
  *
  * The gtt_project_freeze() routine prevents notifiers from being
@@ -247,12 +249,12 @@ GttProject * 	gtt_project_locate_from_id (int prj_id);
  *    Also, it will run the interval-scrub routines at this point.
  *    The scrubbing may cause the indicated interval to be deleted
  *    (e.g. merged into the interval above/below it).   To avoid
- *    a dangleing pointer to freed memory, doon't use the input 
+ *    a dangleing pointer to freed memory, doon't use the input
  *    pointer again; instead replace it with the returned value.
- *    This thaw routine will return a pointer to either the 
+ *    This thaw routine will return a pointer to either the
  *    input interval, or, if it was deleted, to another nearby
  *    interval.
- */ 
+ */
 
 void		gtt_project_freeze (GttProject *prj);
 void		gtt_project_thaw (GttProject *prj);
@@ -266,8 +268,8 @@ void		gtt_project_add_notifier (GttProject *,
 void		gtt_project_remove_notifier (GttProject *,
 			GttProjectChanged, gpointer);
 
-/* These functions provide a generic place to hang arbitrary data 
- *     on the project (used by the GUI). 
+/* These functions provide a generic place to hang arbitrary data
+ *     on the project (used by the GUI).
  */
 gpointer gtt_project_get_private_data (GttProject *);
 void     gtt_project_set_private_data (GttProject *, gpointer);
@@ -278,8 +280,8 @@ void     gtt_project_set_private_data (GttProject *, gpointer);
  *    until all sub-projects have been visited.
  *    This routine returns the value of the last callback.
  *
- * The gtt_project_foreach_interval() routine calls the indicated 
- *    function on each interval of each task in the project.  The 
+ * The gtt_project_foreach_interval() routine calls the indicated
+ *    function on each interval of each task in the project.  The
  *    recursion is stopped if the callback returns zero, otherwise
  *    it continues until each interval has been visited.
  *    This routines does *NOT* visit subprojects.
@@ -288,12 +290,12 @@ void     gtt_project_set_private_data (GttProject *, gpointer);
  * The gtt_project_foreach_subproject_interval() routine works just
  *    like gtt_project_foreach_interval(), except that it also
  *    visits the subprojects of the project.
- *    
- */ 
+ *
+ */
 int      gtt_project_foreach (GttProject *,  GttProjectCB, gpointer);
 int      gtt_project_foreach_interval (GttProject *, GttIntervalCB, gpointer);
 int      gtt_project_foreach_subproject_interval (GttProject *, GttIntervalCB, gpointer);
-		  
+
 
 /* -------------------------------------------------------- */
 /* Project Manipulation */
@@ -301,7 +303,7 @@ int      gtt_project_foreach_subproject_interval (GttProject *, GttIntervalCB, g
 /* The project_timer_start() routine logs the time when
  *    a new task interval starts.
  * The project_timer_update() routine updates the end-time
- *    for a task interval. 
+ *    for a task interval.
  */
 void 		gtt_project_timer_start (GttProject *);
 void 		gtt_project_timer_update (GttProject *);
@@ -324,7 +326,7 @@ void 		gtt_project_timer_stop (GttProject *);
  *    total number of seconds spent on this project,
  *    including a total of all its sub-projects.
  *
- * Design Note: These routines should probably be replaced 
+ * Design Note: These routines should probably be replaced
  * by a generic query mechanism at some point.
  */
 
@@ -355,18 +357,18 @@ void gtt_project_list_compute_secs (void);
 int      gtt_project_total (GttProject *);
 
 
-/* The gtt_project_get_children() returns a list of the 
- *    subprojects of this project 
- *    
+/* The gtt_project_get_children() returns a list of the
+ *    subprojects of this project
+ *
  * The gtt_project_get_tasks() routine returns a list of
  *    tasks associated with this project.
- *    
+ *
  * The gtt_project_get_first_task() returns the task at the head
  *    of the queue (the currently active task).  If this is a new
  *    project, there may not be any tasks, and it would
  *    return NULL.
  *
- * The gtt_project_get_first_interval() routine returns the 
+ * The gtt_project_get_first_interval() routine returns the
  *    interval at the head of the active task (i.e. the currenly
  *    ticking interval, or the last interval to tick).
  */
@@ -377,24 +379,24 @@ GttInterval * gtt_project_get_first_interval (GttProject *);
 
 GttProject * 	gtt_project_get_parent (GttProject *);
 
-/* 
+/*
  * The following routines maintain a heirarchical tree of projects.
  * Note, however, that these routines do not sanity check the tree
  * globally, so it is possible to create loops or disconected
  * components if one is sloppy.
  *
- * The gtt_project_append_project() routine makes 'child' a subproject 
+ * The gtt_project_append_project() routine makes 'child' a subproject
  *    of 'parent'.  In doing this, it removes the child from its
  *    present location (whether as child of a diffferent project,
  *    or from the master project list).  It appends the child
  *    to the parent's list: the child becomes the 'last one'.
- *    If 'parent' is NULL, then the child is appended to the 
+ *    If 'parent' is NULL, then the child is appended to the
  *    top-level project list.
  */
 void	gtt_project_append_project (GttProject *parent, GttProject *child);
 
-/* 
- * The gtt_project_insert_before() routine will insert 'proj' on the 
+/*
+ * The gtt_project_insert_before() routine will insert 'proj' on the
  *     same list as 'before_me', be will insert it before it.  Note
  *     that 'before_me' may be in the top-level list, or it may be
  *     in a subproject list; either way, the routine works.  If
@@ -403,7 +405,7 @@ void	gtt_project_append_project (GttProject *parent, GttProject *child);
  *     being inserted into its new location.
  *
  * The gtt_project_insert_after() routine works similarly, except that
- *     if 'after_me' is null, then the proj is prepended to the 
+ *     if 'after_me' is null, then the proj is prepended to the
  *     master list.
  */
 void	gtt_project_insert_before (GttProject *proj, GttProject *before_me);
@@ -412,9 +414,9 @@ void	gtt_project_insert_after (GttProject *proj, GttProject *after_me);
 void	gtt_project_append_task (GttProject *, GttTask *);
 void	gtt_project_prepend_task (GttProject *, GttTask *);
 
-/* The gtt_clear_daily_counter() will delete all intervals from 
- *    the project that started after midnight.  Typically, this 
- *    will result in the daily counters being zero'ed out, although 
+/* The gtt_clear_daily_counter() will delete all intervals from
+ *    the project that started after midnight.  Typically, this
+ *    will result in the daily counters being zero'ed out, although
  *    if a project started before midnight, some time may remain
  *    on deck.
  */
@@ -423,44 +425,44 @@ void gtt_clear_daily_counter (GttProject *proj);
 
 /* -------------------------------------------------------- */
 /* master project list */
+/* XXX many routines should take the project list as an argument.
+ * Right now its implemented as a global.
+ */
+
+GttProjectList *gtt_project_list_new (void);
+void gtt_project_list_destroy (GttProjectList *);
 
 /* Return a list of all top-level projects */
-GList * 	gtt_get_project_list (void);
+GList * 	gtt_project_list_get_list (GttProjectList *);
 
-/* Append project to the top-level project list */
-void 		gtt_project_list_append(GttProject *p);
-
-void project_list_destroy(void);
+/* Append project to the project list */
+void 		gtt_project_list_append(GttProjectList *, GttProject *p);
 
 /* The 'sort' functions have a sort-of wacky interface.
  * They will sort the list of projects passed as an argument,
- * returning the sorted list.  If the list is the top-level
- * list, it will 'do the right thing'.  If the list is a set
- * of sub-projects of a project, then the parent project
- * will be reparented with them.  Note that this will cause 
- * data loss and destruction, or garbaged trees, etc. if the
- * list that is passed as the argument is *not* the complete
- * list of subprojects for that project.
- * 
+ *
+ * This is fundamentally wrong, sorting should not be done here,
+ * it should be done in the display ("presentation") layer.
+ * But this works for now.
  */
-GList * project_list_sort_current(GList *);
-GList * project_list_sort_day(GList *);
-GList * project_list_sort_yesterday(GList *);
-GList * project_list_sort_week(GList *);
-GList * project_list_sort_lastweek(GList *);
-GList * project_list_sort_month(GList *);
-GList * project_list_sort_year(GList *);
-GList * project_list_sort_ever(GList *);
-GList * project_list_sort_title(GList *);
-GList * project_list_sort_desc(GList *);
-GList * project_list_sort_start(GList *);
-GList * project_list_sort_end(GList *);
-GList * project_list_sort_due(GList *);
-GList * project_list_sort_sizing(GList *);
-GList * project_list_sort_percent(GList *);
-GList * project_list_sort_urgency(GList *);
-GList * project_list_sort_importance(GList *);
-GList * project_list_sort_status(GList *);
+void project_list_sort_current    (GttProjectList *);
+void project_list_sort_day        (GttProjectList *);
+void project_list_sort_yesterday  (GttProjectList *);
+void project_list_sort_week       (GttProjectList *);
+void project_list_sort_lastweek   (GttProjectList *);
+void project_list_sort_month      (GttProjectList *);
+void project_list_sort_year       (GttProjectList *);
+void project_list_sort_ever       (GttProjectList *);
+void project_list_sort_title      (GttProjectList *);
+void project_list_sort_desc       (GttProjectList *);
+void project_list_sort_start      (GttProjectList *);
+void project_list_sort_end        (GttProjectList *);
+void project_list_sort_due        (GttProjectList *);
+void project_list_sort_sizing     (GttProjectList *);
+void project_list_sort_percent    (GttProjectList *);
+void project_list_sort_urgency    (GttProjectList *);
+void project_list_sort_importance (GttProjectList *);
+void project_list_sort_status     (GttProjectList *);
 
 /* The gtt_project_list_total_secs_day() routine returns the
  *    total number of seconds spent on all projects today,
@@ -481,12 +483,12 @@ int      gtt_project_list_total (void);
 
 /* -------------------------------------------------------- */
 /* Tasks */
-/* Taks may be a bit misnamed -- they should ave been called 
+/* Taks may be a bit misnamed -- they should ave been called
  * 'diary entries'.
  */
 
 /* The gtt_task_copy() routine makes a copy of the indicated task.
- *    it copies the memo, notes, and billing info, but not the 
+ *    it copies the memo, notes, and billing info, but not the
  *    intervals, nor the parent.
  */
 
@@ -508,7 +510,7 @@ GttBillRate	gtt_task_get_billrate (GttTask *);
 void		gtt_task_set_billstatus (GttTask *, GttBillStatus);
 GttBillStatus	gtt_task_get_billstatus (GttTask *);
 
-/* The bill_unit is the minimum billable unit of time. 
+/* The bill_unit is the minimum billable unit of time.
  * Typically 15 minutes or an hour, it represents the smallest unit
  * of time that will appear on the invoice.
  */
@@ -524,14 +526,14 @@ int		gtt_task_get_bill_unit (GttTask *);
  *
  * The gtt_task_insert() routine pastes 'insertee' above 'where'.
  *
- * The gtt_task_merge_up() routine will take all of the intervals of 
+ * The gtt_task_merge_up() routine will take all of the intervals of
  *    the indicated task, and move them into the task above, (thus
- *    gutting this task of its intervals).  It does not actually 
+ *    gutting this task of its intervals).  It does not actually
  *    destroy this task.
  *
  * The gtt_task_is_first_task() routine returns True if this task
  *    is the leading task of the project.
- *    
+ *
  * The gtt_task_is_last_task() routine returns True if this task
  *    is the last task of the project.
  */
@@ -548,7 +550,7 @@ GList *  gtt_task_get_intervals (GttTask *);
 void		gtt_task_add_interval (GttTask *, GttInterval *);
 void		gtt_task_append_interval (GttTask *, GttInterval *);
 
-/* gtt_task_get_secs_ever() adds up and returns the total number of 
+/* gtt_task_get_secs_ever() adds up and returns the total number of
  * seconds in the intervals in this task. */
 int     gtt_task_get_secs_ever (GttTask *tsk);
 
@@ -562,27 +564,27 @@ time_t   gtt_task_get_secs_latest (GttTask *tsk);
 /* intervals */
 /* The gtt_interval_set_start() and gtt_interval_set_stop() set the
  *    start and stop times that define the interval.  These routines
- *    will not let you set a start time that is later than the stop 
+ *    will not let you set a start time that is later than the stop
  *    time: negative timer intervals are not allowed.  Note also that
- *    the system automatically removes ("scrubs away") short time 
- *    intervals when certain key operations are performed (e.g. 'thaw'). 
- *    This means that if you are holding a pointer to a very 
- *    short interval, it might disappear on you.  In other words, 
- *    don't use these routines to set a short time interval, and 
+ *    the system automatically removes ("scrubs away") short time
+ *    intervals when certain key operations are performed (e.g. 'thaw').
+ *    This means that if you are holding a pointer to a very
+ *    short interval, it might disappear on you.  In other words,
+ *    don't use these routines to set a short time interval, and
  *    still expect the interval to be around when you are done.
- *    
+ *
  *    This is a rather unsatisfactory state of affairs; however,
  *    I don't know how else to auto-scrub intervals and also allow
- *    users to hold pointers to them.  If you want to get back a 
- *    pointer to a valid interval, use the pointer returned by 
+ *    users to hold pointers to them.  If you want to get back a
+ *    pointer to a valid interval, use the pointer returned by
  *    gtt_interval_thaw().
  *
- * The fuzz (measured in seconds) indicates how 'fuzzy' the 
+ * The fuzz (measured in seconds) indicates how 'fuzzy' the
  *    true start time was.  Typically, its 0, 300, 3600 or 12*3600
- *    Just because the start time is fuzy doesn't mean that the total 
- *    interval is inaccurate: the delta stop-start is still accurate 
+ *    Just because the start time is fuzy doesn't mean that the total
+ *    interval is inaccurate: the delta stop-start is still accurate
  *    down to the second.  The fuzz is 'merely' used by the GUI
- *    to help the user report time spent post-facto, without having 
+ *    to help the user report time spent post-facto, without having
  *    to exactly nail down the start time.
  *
  * The is_running flag indicates whether the timer is running on this
@@ -600,12 +602,12 @@ time_t    gtt_interval_get_stop (GttInterval *);
 gboolean  gtt_interval_is_running (GttInterval *);
 int       gtt_interval_get_fuzz (GttInterval *);
 
-/* The gtt_interval_new_insert_after() routine creates a new interval 
- *    and inserts it after the interval "where".  It returns the new 
+/* The gtt_interval_new_insert_after() routine creates a new interval
+ *    and inserts it after the interval "where".  It returns the new
  *    interval.
  *
- * The gtt_interval_merge_up() routine merges the given interval with 
- *    the immediately more recent one above it.  It does this by 
+ * The gtt_interval_merge_up() routine merges the given interval with
+ *    the immediately more recent one above it.  It does this by
  *    decrementing the start time.  The resulting interval has the
  *    max of the two fuzz factors, and is running if the first was.
  *    The merged interval is returned.
@@ -613,9 +615,9 @@ int       gtt_interval_get_fuzz (GttInterval *);
  * The gtt_interval_merge_down() routine does the same, except that
  *    it merges with the next interval by incrementing its stop time.
  *
- * The gtt_interval_split() routine splits the list of intervals 
+ * The gtt_interval_split() routine splits the list of intervals
  *    into two pieces, with the indicated interval and everything
- *    following it going after the specified.  
+ *    following it going after the specified.
  */
 GttInterval *   gtt_interval_new_insert_after (GttInterval *where);
 GttInterval *   gtt_interval_merge_up (GttInterval *);
