@@ -91,8 +91,8 @@ save_task_notes(GtkWidget *w, PropTaskDlg *dlg)
 	} 
 	else 
 	{
-		gtt_task_set_memo(dlg->task, _("empty"));
-		gtk_entry_set_text(dlg->memo, _("empty"));
+		gtt_task_set_memo(dlg->task, "");
+		gtk_entry_set_text(dlg->memo, "");
 	}
 
 	str = xxxgtk_textview_get_text(dlg->notes);
@@ -270,7 +270,7 @@ prop_task_dialog_new (void)
 	dlg->dlg = GTK_DIALOG (glade_xml_get_widget (gtxml,  "Task Properties"));
 
 	glade_xml_signal_connect_data (gtxml, "on_help_button_clicked",
-		GTK_SIGNAL_FUNC (gtt_help_popup), "gnotime.xml#preferences");
+		GTK_SIGNAL_FUNC (gtt_help_popup), "properties");
 
 	glade_xml_signal_connect_data (gtxml, "on_ok_button_clicked",
 		GTK_SIGNAL_FUNC (close_cb), dlg);
